@@ -10,5 +10,5 @@ __all__ = [
     'wrapper',
 ]
 
-name = "tatsumaki.py"
-version = "0.3"
+name = "tatsu.py"
+version = "1.0.2"
